@@ -25,9 +25,8 @@
 #include "config.h"
 
 #include "seahorse-application.h"
-#include "seahorse-icons.h"
+#include "seahorse-common.h"
 
-#include "gkr/seahorse-gkr.h"
 #include "pgp/seahorse-pgp.h"
 #include "ssh/seahorse-ssh.h"
 
@@ -94,6 +93,8 @@ seahorse_application_finalize (GObject *gobject)
 void seahorse_pkcs11_backend_initialize (void);
 #endif
 
+void seahorse_gkr_backend_initialize (void);
+
 static void
 seahorse_application_startup (GApplication *application)
 {
