@@ -27,7 +27,6 @@
 #define SECRET_API_SUBJECT_TO_CHANGE
 #include <libsecret/secret.h>
 
-#include "seahorse-backend.h"
 #include "seahorse-predicate.h"
 #include "seahorse-common.h"
 #include "seahorse-widget.h"
@@ -287,7 +286,7 @@ handle_activate_result (SeahorseShellSearchProvider2 *skeleton,
 	window = GTK_WINDOW (seahorse_widget_get_widget (key_manager, key_manager->name));
 	gtk_window_present_with_time (window, timestamp);
 
-	seahorse_viewable_show_viewer (SEAHORSE_VIEWABLE (object), window);
+	seahorse_viewable_view (object, window);
 
 	seahorse_shell_search_provider2_complete_activate_result (skeleton,
 	                                                          invocation);
