@@ -34,10 +34,8 @@
 #include "seahorse-pgp-key.h"
 
 #include "seahorse-common.h"
-#include "seahorse-icons.h"
 #include "seahorse-predicate.h"
 #include "seahorse-object-list.h"
-#include "seahorse-place.h"
 #include "seahorse-util.h"
 
 #include <glib/gi18n.h>
