@@ -27,7 +27,7 @@
 #include "seahorse-gpgme-key-op.h"
 #include "seahorse-gpgme-secret-deleter.h"
 
-#include "seahorse-delete-dialog.h"
+#include "seahorse-common.h"
 
 #include <glib/gi18n.h>
 
@@ -83,7 +83,7 @@ seahorse_gpgme_secret_deleter_create_confirm (SeahorseDeleter *deleter,
 	seahorse_delete_dialog_set_check_require (SEAHORSE_DELETE_DIALOG (dialog), TRUE);
 
 	g_free (prompt);
-	return dialog;
+	return g_object_ref (dialog);
 }
 
 static GList *
