@@ -35,9 +35,7 @@
 #include "seahorse-servers.h"
 
 #include "seahorse-object-list.h"
-#include "seahorse-place.h"
 #include "seahorse-progress.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 
 #include <libsoup/soup.h>
@@ -116,74 +114,6 @@ get_http_server_uri (SeahorseHKPSource *self, const char *path)
     return uri;
 }
 
-static gboolean
-check_for_http_proxy_schema__with_love_to_ryan ()
-{
-	const gchar * const* schemas;
-	guint i;
-
-	/*
-	 * This isn't very efficient, but it's the only way to use this schema
-	 * without our GSettings killing our process if the schema doesn't exist.
-	 *
-	 * Groan.
-	 */
-
-	schemas = g_settings_list_schemas ();
-	for (i = 0; schemas[i] != NULL; i++) {
-		if (g_str_equal (schemas[i], "org.gnome.system.proxy.http"))
-			return TRUE;
-	}
-
-	return FALSE;
-}
-
-static SoupSession *
-create_proxy_session (void)
-{
-	SoupSession *session = NULL;
-	SoupURI *uri;
-	GSettings *settings;
-	gchar *host;
-	gchar *user;
-	gchar *password;
-
-	if (!check_for_http_proxy_schema__with_love_to_ryan ())
-		return NULL;
-
-	settings = g_settings_new ("org.gnome.system.proxy.http");
-	if (g_settings_get_boolean (settings, "enabled")) {
-		host = g_settings_get_string (settings, "host");
-		if (host) {
-			uri = soup_uri_new (NULL);
-			if (!uri) {
-				g_warning ("creation of SoupURI from '%s' failed", host);
-			} else {
-				soup_uri_set_scheme (uri, SOUP_URI_SCHEME_HTTP);
-				soup_uri_set_host (uri, host);
-			}
-			g_free (host);
-			soup_uri_set_port (uri, g_settings_get_int (settings, "port"));
-
-			if (g_settings_get_boolean (settings, "use-authentication")) {
-				user = g_settings_get_string (settings, "authentication-user");
-				soup_uri_set_user (uri, user);
-				g_free (user);
-
-				password = g_settings_get_string (settings, "authentication-password");
-				soup_uri_set_password (uri, password);
-				g_free (password);
-			}
-
-			session = soup_session_async_new_with_options (SOUP_SESSION_PROXY_URI, uri, NULL);
-			soup_uri_free (uri);
-		}
-	}
-
-	g_object_unref (settings);
-	return session;
-}
-
 static SoupSession *
 create_hkp_soup_session (void)
 {
@@ -192,11 +122,10 @@ create_hkp_soup_session (void)
 	SoupLogger *logger;
 #endif
 
-	session = create_proxy_session ();
+        session = soup_session_async_new_with_options (SOUP_SESSION_ADD_FEATURE_BY_TYPE,
+                                                       SOUP_TYPE_PROXY_RESOLVER_DEFAULT,
+                                                       NULL);
 
-	/* Without a proxy */
-	if (session == NULL)
-		session = soup_session_async_new ();
 
 #if WITH_DEBUG
 	if (seahorse_debugging) {
@@ -560,10 +489,7 @@ detect_key (const gchar *text, gint len, const gchar **start, const gchar **end)
  *  SEAHORSE HKP SOURCE
  */
 
-static void seahorse_place_iface (SeahorsePlaceIface *iface);
-
-G_DEFINE_TYPE_EXTENDED (SeahorseHKPSource, seahorse_hkp_source, SEAHORSE_TYPE_SERVER_SOURCE, 0,
-                        G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_PLACE, seahorse_place_iface));
+G_DEFINE_TYPE (SeahorseHKPSource, seahorse_hkp_source, SEAHORSE_TYPE_SERVER_SOURCE);
 
 static void 
 seahorse_hkp_source_init (SeahorseHKPSource *hsrc)
@@ -1094,18 +1020,6 @@ seahorse_hkp_source_export_finish (SeahorseServerSource *source,
 	return output;
 }
 
-/**
-* iface: The interface to set
-*
-* Set up the default SeahorseSourceIface
-*
-**/
-static void 
-seahorse_place_iface (SeahorsePlaceIface *iface)
-{
-
-}
-
 /**
 * klass:
 *
