@@ -34,10 +34,9 @@
 #include "seahorse-pgp-subkey.h"
 #include "seahorse-pgp-uid.h"
 
+#include "seahorse-common.h"
 #include "seahorse-object-list.h"
-#include "seahorse-place.h"
 #include "seahorse-progress.h"
-#include "seahorse-registry.h"
 #include "seahorse-servers.h"
 #include "seahorse-util.h"
 
@@ -736,10 +735,7 @@ seahorse_ldap_source_connect_finish (SeahorseLDAPSource *source,
 	return ldap;
 }
 
-static void seahorse_place_iface (SeahorsePlaceIface *iface);
-
-G_DEFINE_TYPE_EXTENDED (SeahorseLDAPSource, seahorse_ldap_source, SEAHORSE_TYPE_SERVER_SOURCE, 0,
-                        G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_PLACE, seahorse_place_iface));
+G_DEFINE_TYPE (SeahorseLDAPSource, seahorse_ldap_source, SEAHORSE_TYPE_SERVER_SOURCE);
 
 static void 
 seahorse_ldap_source_init (SeahorseLDAPSource *self)
@@ -1426,11 +1422,6 @@ seahorse_ldap_source_export_finish (SeahorseServerSource *source,
 	return output;
 }
 
-static void 
-seahorse_place_iface (SeahorsePlaceIface *iface)
-{
-}
-
 /* Initialize the basic class stuff */
 static void
 seahorse_ldap_source_class_init (SeahorseLDAPSourceClass *klass)
