@@ -34,12 +34,9 @@
 #include "seahorse-keyserver-search.h"
 #include "seahorse-keyserver-sync.h"
 
-#include "seahorse-action.h"
-#include "seahorse-actions.h"
-#include "seahorse-delete-dialog.h"
+#include "seahorse-common.h"
 #include "seahorse-object.h"
 #include "seahorse-object-list.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 
 GType   seahorse_pgp_backend_actions_get_type         (void) G_GNUC_CONST;
@@ -101,6 +98,7 @@ on_remote_sync (GtkAction* action,
 		}
 		g_list_free (objects);
 	}
+	g_object_unref (catalog);
 
 	if (keys == NULL) {
 		keyring = seahorse_pgp_backend_get_default_keyring (NULL);
