@@ -21,7 +21,7 @@
 
 #include "config.h"
 
-#include "seahorse-context.h"
+#include "seahorse-application.h"
 #include "seahorse-collection.h"
 #include "seahorse-object.h"
 #include "seahorse-predicate.h"
@@ -79,7 +79,7 @@ seahorse_keyset_pgp_signers_new (void)
 	collection = seahorse_collection_new_for_predicate (GCR_COLLECTION (keyring),
 	                                                    predicate, g_free);
 
-	g_signal_connect_object (seahorse_context_pgp_settings (NULL), "changed::default-key",
+	g_signal_connect_object (seahorse_application_pgp_settings (NULL), "changed::default-key",
 	                         G_CALLBACK (on_settings_default_key_changed), collection, 0);
 
 	return GCR_COLLECTION (collection);
