@@ -25,8 +25,7 @@
 #include "seahorse-pgp-key.h"
 #include "seahorse-unknown-source.h"
 
-#include "seahorse-place.h"
-#include "seahorse-registry.h"
+#include "seahorse-common.h"
 #include "seahorse-unknown.h"
 
 #include <gcr/gcr-base.h>
@@ -68,25 +67,76 @@ seahorse_unknown_source_init (SeahorseUnknownSource *self)
 	                                    g_free, g_object_unref);
 }
 
+static void
+seahorse_unknown_source_load (SeahorsePlace *self,
+                              GCancellable *cancellable,
+                              GAsyncReadyCallback callback,
+                              gpointer user_data)
+{
+	g_return_if_reached ();
+}
+
+static gboolean
+seahorse_unknown_source_load_finish (SeahorsePlace *self,
+                                     GAsyncResult *res,
+                                     GError **error)
+{
+	g_return_val_if_reached (FALSE);
+}
+
+static gchar *
+seahorse_unknown_source_get_label (SeahorsePlace* self)
+{
+	return g_strdup ("");
+}
+
+static gchar *
+seahorse_unknown_source_get_description (SeahorsePlace* self)
+{
+	return NULL;
+}
+
+static gchar *
+seahorse_unknown_source_get_uri (SeahorsePlace* self)
+{
+	return NULL;
+}
+
+static GIcon *
+seahorse_unknown_source_get_icon (SeahorsePlace* self)
+{
+	return NULL;
+}
+
+static GtkActionGroup *
+seahorse_unknown_source_get_actions (SeahorsePlace* self)
+{
+	return NULL;
+}
+
 static void
 seahorse_unknown_source_get_property (GObject *obj,
                                       guint prop_id,
                                       GValue *value,
                                       GParamSpec *pspec)
 {
+	SeahorsePlace *place = SEAHORSE_PLACE (obj);
+
 	switch (prop_id) {
 	case PROP_LABEL:
-		g_value_set_string (value, "");
+		g_value_take_string (value, seahorse_unknown_source_get_label (place));
 		break;
 	case PROP_DESCRIPTION:
+		g_value_take_string (value, seahorse_unknown_source_get_description (place));
+		break;
 	case PROP_URI:
-		g_value_set_string (value, NULL);
+		g_value_take_string (value, seahorse_unknown_source_get_uri (place));
 		break;
 	case PROP_ICON:
-		g_value_set_object (value, NULL);
+		g_value_take_object (value, seahorse_unknown_source_get_icon (place));
 		break;
 	case PROP_ACTIONS:
-		g_value_set_object (value, NULL);
+		g_value_take_object (value, seahorse_unknown_source_get_actions (place));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
@@ -153,7 +203,13 @@ seahorse_unknown_source_collection_iface (GcrCollectionIface *iface)
 static void
 seahorse_unknown_source_place_iface (SeahorsePlaceIface *iface)
 {
-	/* no implementation */
+	iface->load = seahorse_unknown_source_load;
+	iface->load_finish = seahorse_unknown_source_load_finish;
+	iface->get_actions = seahorse_unknown_source_get_actions;
+	iface->get_description = seahorse_unknown_source_get_description;
+	iface->get_icon = seahorse_unknown_source_get_icon;
+	iface->get_label = seahorse_unknown_source_get_label;
+	iface->get_uri = seahorse_unknown_source_get_uri;
 }
 
 SeahorseUnknownSource*
