@@ -21,6 +21,7 @@
  */
 
 #include "config.h"
+#include "seahorse-common.h"
 
 #include "seahorse-certificate.h"
 #include "seahorse-pkcs11.h"
@@ -29,9 +30,7 @@
 #include "seahorse-pkcs11-properties.h"
 #include "seahorse-private-key.h"
 #include "seahorse-token.h"
-#include "seahorse-types.h"
 
-#include "seahorse-common.h"
 #include "seahorse-util.h"
 #include "seahorse-validity.h"
 
@@ -413,18 +412,19 @@ seahorse_certificate_deletable_iface (SeahorseDeletableIface *iface)
 	iface->get_deletable = seahorse_certificate_get_deletable;
 }
 
-static void
-seahorse_certificate_show_viewer (SeahorseViewable *viewable,
-                                  GtkWindow *parent)
+static GtkWindow *
+seahorse_certificate_create_viewer (SeahorseViewable *viewable,
+                                    GtkWindow *parent)
 {
-	GtkWindow *viewer = seahorse_pkcs11_properties_show (G_OBJECT (viewable), parent);
+	GtkWindow *viewer = seahorse_pkcs11_properties_new (G_OBJECT (viewable), parent);
 	gtk_widget_show (GTK_WIDGET (viewer));
+	return viewer;
 }
 
 static void
 seahorse_certificate_viewable_iface (SeahorseViewableIface *iface)
 {
-	iface->show_viewer = seahorse_certificate_show_viewer;
+	iface->create_viewer = seahorse_certificate_create_viewer;
 }
 
 GIcon *
