@@ -21,15 +21,15 @@
  */
 
 #include "config.h"
+#include "seahorse-common.h"
 
 #include "seahorse-pkcs11-backend.h"
 #include "seahorse-pkcs11-generate.h"
 #include "seahorse-token.h"
 
-#include "seahorse-action.h"
+#include "seahorse-common.h"
 #include "seahorse-progress.h"
 #include "seahorse-interaction.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 
 #include <glib/gi18n.h>
@@ -113,7 +113,7 @@ complete_generate (SeahorsePkcs11Generate *self,
 	if (*error != NULL)
 		seahorse_util_handle_error (error, NULL, _("Couldn't generate private key"));
 	else
-		seahorse_place_load_async (SEAHORSE_PLACE (self->token), self->cancellable, NULL, NULL);
+		seahorse_place_load (SEAHORSE_PLACE (self->token), self->cancellable, NULL, NULL);
 
 	g_clear_object (&self->cancellable);
 	gck_attributes_unref (self->pub_attrs);
@@ -515,5 +515,5 @@ seahorse_pkcs11_generate_register (void)
 	actions = gtk_action_group_new ("pkcs11-generate");
 	gtk_action_group_set_translation_domain (actions, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (actions, ACTION_ENTRIES, G_N_ELEMENTS (ACTION_ENTRIES), NULL);
-	seahorse_registry_register_object (NULL, G_OBJECT (actions), "generator", NULL);
+	seahorse_registry_register_object (G_OBJECT (actions), "generator");
 }
