@@ -25,10 +25,8 @@
 #include "seahorse-pkcs11-request.h"
 #include "seahorse-token.h"
 
-#include "seahorse-action.h"
 #include "seahorse-progress.h"
 #include "seahorse-interaction.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 
 #include <glib/gi18n.h>
