@@ -22,6 +22,7 @@
 
 #include "config.h"
 
+#include "seahorse-application.h"
 #include "seahorse-generate-select.h"
 #include "seahorse-import-dialog.h"
 #include "seahorse-key-manager.h"
@@ -29,7 +30,6 @@
 #include "seahorse-sidebar.h"
 
 #include "seahorse-collection.h"
-#include "seahorse-registry.h"
 #include "seahorse-progress.h"
 #include "seahorse-util.h"
 
@@ -41,24 +41,6 @@ enum {
 	SHOW_TRUSTED,
 };
 
-void           on_keymanager_row_activated              (GtkTreeView* view,
-                                                         GtkTreePath* path,
-                                                         GtkTreeViewColumn* column,
-                                                         SeahorseKeyManager* self);
-
-gboolean       on_keymanager_key_list_button_pressed    (GtkTreeView* view,
-                                                         GdkEventButton* event,
-                                                         SeahorseKeyManager* self);
-
-gboolean       on_keymanager_key_list_popup_menu        (GtkTreeView* view,
-                                                         SeahorseKeyManager* self);
-
-void           on_keymanager_new_button                 (GtkButton* button,
-                                                         SeahorseKeyManager* self);
-
-void           on_keymanager_import_button              (GtkButton* button,
-                                                         SeahorseKeyManager* self);
-
 struct _SeahorseKeyManagerPrivate {
 	GtkActionGroup* view_actions;
 	GtkRadioAction *show_action;
@@ -106,7 +88,7 @@ on_view_selection_changed (GtkTreeSelection* selection, SeahorseKeyManager* self
 	g_idle_add ((GSourceFunc)fire_selection_changed, self);
 }
 
-G_MODULE_EXPORT void
+static void
 on_keymanager_row_activated (GtkTreeView* view, GtkTreePath* path, 
                                   GtkTreeViewColumn* column, SeahorseKeyManager* self) 
 {
@@ -122,7 +104,7 @@ on_keymanager_row_activated (GtkTreeView* view, GtkTreePath* path,
 		seahorse_catalog_show_properties (SEAHORSE_CATALOG (self), obj);
 }
 
-G_MODULE_EXPORT gboolean
+static gboolean
 on_keymanager_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event, SeahorseKeyManager* self) 
 {
 	g_return_val_if_fail (SEAHORSE_IS_KEY_MANAGER (self), FALSE);
@@ -136,7 +118,7 @@ on_keymanager_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event,
 	return FALSE;
 }
 
-G_MODULE_EXPORT gboolean
+static gboolean
 on_keymanager_key_list_popup_menu (GtkTreeView* view, SeahorseKeyManager* self) 
 {
 	GList *objects;
@@ -158,7 +140,7 @@ on_file_new (GtkAction* action, SeahorseKeyManager* self)
 	seahorse_generate_select_show (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)));
 }
 
-G_MODULE_EXPORT void 
+static void
 on_keymanager_new_button (GtkButton* button, SeahorseKeyManager* self) 
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
@@ -180,7 +162,7 @@ on_first_timer (SeahorseKeyManager* self)
 	 */
 
 	if (gcr_collection_get_length (GCR_COLLECTION (self->pv->collection)) == 0) {
-		widget = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "first-time-box");
+		widget = xxwidget_get_widget (XX_WIDGET (self), "first-time-box");
 		gtk_widget_show (widget);
 	}
 	
@@ -330,7 +312,7 @@ on_key_import_file (GtkAction* action, SeahorseKeyManager* self)
 	import_prompt (self);
 }
 
-G_MODULE_EXPORT void 
+static void
 on_keymanager_import_button (GtkButton* button, SeahorseKeyManager* self) 
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
@@ -382,12 +364,25 @@ on_target_drag_data_received (GtkWindow* window, GdkDragContext* context, gint x
 	}
 }
 
+static void
+update_clipboard_state (GtkClipboard* clipboard, GdkEvent* event, GtkActionGroup* group)
+{
+	GtkAction *action;
+	gboolean text_available;
+
+	text_available = gtk_clipboard_wait_is_text_available (clipboard);
+	action = gtk_action_group_get_action (group, "edit-import-clipboard");
+	gtk_action_set_sensitive (action, text_available);
+}
+
 static void 
 on_clipboard_received (GtkClipboard* board, const char* text, SeahorseKeyManager* self) 
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_CLIPBOARD (board));
-	g_return_if_fail (text != NULL);
+
+	if (text == NULL)
+		return;
 
 	g_assert(self->pv->filter_entry);
 	if (gtk_widget_is_focus (GTK_WIDGET (self->pv->filter_entry)) == TRUE)
@@ -519,16 +514,16 @@ static const GtkActionEntry GENERAL_ACTIONS[] = {
 };
 
 static const GtkToggleActionEntry SIDEBAR_ACTIONS[] = {
-	{ "view-sidebar", NULL, N_("By _keyring"), NULL,
+	{ "view-sidebar", NULL, N_("By _Keyring"), NULL,
 	  N_("Show sidebar listing keyrings"), NULL, FALSE },
 };
 
 static const GtkRadioActionEntry VIEW_RADIO_ACTIONS[] = {
-	{ "view-personal", NULL, N_("Show _personal"), NULL,
+	{ "view-personal", NULL, N_("Show _Personal"), NULL,
 	  N_("Only show personal keys, certificates and passwords"), SHOW_PERSONAL },
-	{ "view-trusted", NULL, N_("Show _trusted"), NULL,
+	{ "view-trusted", NULL, N_("Show _Trusted"), NULL,
 	  N_("Only show trusted keys, certificates and passwords"), SHOW_TRUSTED },
-	{ "view-any", NULL, N_("Show _any"), NULL,
+	{ "view-any", NULL, N_("Show _Any"), NULL,
 	  N_("Show all keys, certificates and passwords"), SHOW_ANY },
 };
 
@@ -592,11 +587,13 @@ setup_sidebar (SeahorseKeyManager *self)
 	GtkActionGroup *actions;
 	GtkAction *action;
 	GList *backends, *l;
+	GtkBuilder *builder;
 
 	self->pv->sidebar = seahorse_sidebar_new ();
 
 	self->pv->sidebar_width = g_settings_get_int (self->pv->settings, "sidebar-width");
-	panes = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "sidebar-panes");
+	builder = seahorse_catalog_get_builder (SEAHORSE_CATALOG (self));
+	panes = GTK_WIDGET (gtk_builder_get_object (builder, "sidebar-panes"));
 	gtk_paned_set_position (GTK_PANED (panes), self->pv->sidebar_width);
 	g_signal_connect (panes, "realize", G_CALLBACK (on_panes_realize), self);
 	g_signal_connect (panes, "unrealize", G_CALLBACK (on_panes_unrealize), self);
@@ -615,7 +612,7 @@ setup_sidebar (SeahorseKeyManager *self)
 		}
 	}
 
-	area = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "sidebar-area");
+	area = GTK_WIDGET (gtk_builder_get_object (builder, "sidebar-area"));
 	gtk_container_add (GTK_CONTAINER (area), GTK_WIDGET (self->pv->sidebar));
 	gtk_widget_show (GTK_WIDGET (self->pv->sidebar));
 
@@ -652,15 +649,22 @@ seahorse_key_manager_constructed (GObject *object)
 	GtkTreeSelection *selection;
 	GtkWidget* widget;
 	GtkAction *action;
+	GtkWindow *window;
+	GtkBuilder *builder;
+	GtkClipboard* clipboard;
 
 	G_OBJECT_CLASS (seahorse_key_manager_parent_class)->constructed (object);
 
+	window = seahorse_catalog_get_window (SEAHORSE_CATALOG (self));
+	gtk_window_set_default_geometry(window, 640, 476);
+	gtk_widget_set_events (GTK_WIDGET (window), GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 	gtk_window_set_title (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)), _("Passwords and Keys"));
 
 	self->pv->collection = setup_sidebar (self);
 
 	/* Init key list & selection settings */
-	self->pv->view = GTK_TREE_VIEW (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "key-list"));
+	builder = seahorse_catalog_get_builder (SEAHORSE_CATALOG (self));
+	self->pv->view = GTK_TREE_VIEW (gtk_builder_get_object (builder, "key-list"));
 	g_return_if_fail (self->pv->view != NULL);
 
 	selection = gtk_tree_view_get_selection (self->pv->view);
@@ -695,17 +699,23 @@ seahorse_key_manager_constructed (GObject *object)
 	on_item_filter_changed (self->pv->settings, "item-filter", self);
 
 	/* first time signals */
-	g_signal_connect_object (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "import-button"), 
+	g_signal_connect_object (gtk_builder_get_object (builder, "import-button"),
 	                         "clicked", G_CALLBACK (on_keymanager_import_button), self, 0);
 
-	g_signal_connect_object (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "new-button"), 
+	g_signal_connect_object (gtk_builder_get_object (builder, "new-button"),
 	                         "clicked", G_CALLBACK (on_keymanager_new_button), self, 0);
 
+	/* Make sure import is only available with clipboard content */
+	action = gtk_action_group_get_action (actions, "edit-import-clipboard");
+	clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
+	g_signal_connect (clipboard, "owner-change", G_CALLBACK (update_clipboard_state), actions);
+	update_clipboard_state (clipboard, NULL, actions);
+
 	/* Flush all updates */
 	seahorse_catalog_ensure_updated (SEAHORSE_CATALOG (self));
 	
 	/* Find the toolbar */
-	widget = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "toolbar-placeholder");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "toolbar-placeholder"));
 	if (widget != NULL) {
 		GList* children = gtk_container_get_children ((GTK_CONTAINER (widget)));
 		if (children != NULL && children->data != NULL) {
@@ -763,7 +773,7 @@ seahorse_key_manager_constructed (GObject *object)
 	g_signal_emit_by_name (self, "selection-changed");
 
 	/* To avoid flicker */
-	seahorse_widget_show (SEAHORSE_WIDGET (SEAHORSE_CATALOG (self)));
+	gtk_widget_show (GTK_WIDGET (self));
 	
 	/* Setup drops */
 	gtk_drag_dest_set (GTK_WIDGET (seahorse_catalog_get_window (SEAHORSE_CATALOG (self))),
@@ -776,6 +786,13 @@ seahorse_key_manager_constructed (GObject *object)
 	g_signal_connect_object (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)), "drag-data-received",
 	                         G_CALLBACK (on_target_drag_data_received), self, 0);
 
+	g_signal_connect (self->pv->view, "button-press-event",
+	                  G_CALLBACK (on_keymanager_key_list_button_pressed), self);
+	g_signal_connect (self->pv->view, "row-activated",
+	                  G_CALLBACK (on_keymanager_row_activated), self);
+	g_signal_connect (self->pv->view, "popup-menu",
+	                  G_CALLBACK (on_keymanager_key_list_popup_menu), self);
+
 #ifdef REFACTOR_FIRST
 	/* To show first time dialog */
 	g_timeout_add_seconds (1, (GSourceFunc)on_first_timer, self);
@@ -828,11 +845,5 @@ seahorse_key_manager_class_init (SeahorseKeyManagerClass *klass)
 void
 seahorse_key_manager_show (void)
 {
-	SeahorseWidget *self;
-
-	self = seahorse_widget_find ("key-manager");
-	if (self != NULL)
-		gtk_window_present (GTK_WINDOW (seahorse_widget_get_widget (self, self->name)));
-	else
-		g_object_new (SEAHORSE_TYPE_KEY_MANAGER, "name", "key-manager", NULL);
+	g_object_new (SEAHORSE_TYPE_KEY_MANAGER, "ui-name", "key-manager", NULL);
 }
