@@ -23,20 +23,10 @@
 
 #include "seahorse-sidebar.h"
 
-#include "seahorse-action.h"
-#include "seahorse-actions.h"
-#include "seahorse-backend.h"
 #include "seahorse-common.h"
 #include "seahorse-interaction.h"
-#include "seahorse-lockable.h"
-#include "seahorse-place.h"
 #include "seahorse-util.h"
 
-#include "gkr/seahorse-gkr.h"
-#include "pgp/seahorse-pgp.h"
-#include "pkcs11/seahorse-pkcs11.h"
-#include "ssh/seahorse-ssh.h"
-
 #include <glib/gi18n.h>
 
 struct _SeahorseSidebar {
@@ -580,8 +570,8 @@ on_cell_renderer_action_icon (GtkTreeViewColumn *column,
 	lockable = lookup_lockable_for_iter (model, iter);
 
 	if (lockable) {
-		can_lock = seahorse_lockable_can_lock (lockable);
-		can_unlock = seahorse_lockable_can_unlock (lockable);
+		can_lock = seahorse_lockable_can_lock (G_OBJECT (lockable));
+		can_unlock = seahorse_lockable_can_unlock (G_OBJECT (lockable));
 	}
 
 	if (can_lock || can_unlock) {
@@ -750,13 +740,13 @@ order_from_backend (GObject *backend)
 
 	if (name == NULL)
 		order = 10;
-	else if (g_str_equal (name, SEAHORSE_GKR_NAME))
+	else if (g_str_equal (name, "gkr"))
 		order = 0;
-	else if (g_str_equal (name, SEAHORSE_PGP_NAME))
+	else if (g_str_equal (name, "pgp"))
 		order = 1;
-	else if (g_str_equal (name, SEAHORSE_PKCS11_NAME))
+	else if (g_str_equal (name, "pkcs11"))
 		order = 2;
-	else if (g_str_equal (name, SEAHORSE_SSH_NAME))
+	else if (g_str_equal (name, "ssh"))
 		order = 3;
 	else
 		order = 10;
@@ -817,8 +807,8 @@ place_lock (SeahorseLockable *lockable,
 	GCancellable *cancellable = g_cancellable_new ();
 	GTlsInteraction *interaction = seahorse_interaction_new (window);
 
-	seahorse_lockable_lock_async (lockable, interaction, cancellable,
-	                              on_place_locked, g_object_ref (window));
+	seahorse_lockable_lock (lockable, interaction, cancellable,
+	                        on_place_locked, g_object_ref (window));
 
 	g_object_unref (cancellable);
 	g_object_unref (interaction);
@@ -856,8 +846,8 @@ place_unlock (SeahorseLockable *lockable,
 	GCancellable *cancellable = g_cancellable_new ();
 	GTlsInteraction *interaction = seahorse_interaction_new (window);
 
-	seahorse_lockable_unlock_async (lockable, interaction, cancellable,
-	                                on_place_unlocked, g_object_ref (window));
+	seahorse_lockable_unlock (lockable, interaction, cancellable,
+	                          on_place_unlocked, g_object_ref (window));
 
 	g_object_unref (cancellable);
 	g_object_unref (interaction);
@@ -907,9 +897,8 @@ static void
 on_place_properties (GtkMenuItem *item,
                      gpointer user_data)
 {
-	SeahorseViewable *viewable = SEAHORSE_VIEWABLE (user_data);
 	GtkWidget *window = gtk_widget_get_toplevel (GTK_WIDGET (item));
-	seahorse_viewable_show_viewer (viewable, GTK_WINDOW (window));
+	seahorse_viewable_view (user_data, GTK_WINDOW (window));
 }
 
 static void
@@ -1188,9 +1177,9 @@ on_tree_view_button_release_event (GtkWidget *widget,
 
 	lockable = lookup_lockable_for_iter (model, &iter);
 	if (lockable) {
-		if (seahorse_lockable_can_lock (lockable))
+		if (seahorse_lockable_can_lock (G_OBJECT (lockable)))
 			place_lock (lockable, GTK_WINDOW (window));
-		else if (seahorse_lockable_can_unlock (lockable))
+		else if (seahorse_lockable_can_unlock (G_OBJECT (lockable)))
 			place_unlock (lockable, GTK_WINDOW (window));
 	}
 
@@ -1367,7 +1356,7 @@ seahorse_sidebar_dispose (GObject *obj)
 {
 	SeahorseSidebar *self = SEAHORSE_SIDEBAR (obj);
 	GList *places, *l;
-	gint i;
+	guint i;
 
 	for (i = 0; i < self->backends->len; i++) {
 		g_signal_handlers_disconnect_by_func (self->backends->pdata[i], on_place_added, self);
