@@ -25,7 +25,7 @@
 #include "seahorse-ssh-dialogs.h"
 #include "seahorse-ssh-source.h"
 
-#include "seahorse-backend.h"
+#include "seahorse-common.h"
 
 #include <glib/gi18n.h>
 
@@ -74,7 +74,31 @@ seahorse_ssh_backend_constructed (GObject *obj)
 	G_OBJECT_CLASS (seahorse_ssh_backend_parent_class)->constructed (obj);
 
 	self->dot_ssh = seahorse_ssh_source_new ();
-	seahorse_place_load_async (SEAHORSE_PLACE (self->dot_ssh), NULL, NULL, NULL);
+	seahorse_place_load (SEAHORSE_PLACE (self->dot_ssh), NULL, NULL, NULL);
+}
+
+static const gchar *
+seahorse_ssh_backend_get_name (SeahorseBackend *backend)
+{
+	return SEAHORSE_SSH_NAME;
+}
+
+static const gchar *
+seahorse_ssh_backend_get_label (SeahorseBackend *backend)
+{
+	return _("Secure Shell");
+}
+
+static const gchar *
+seahorse_ssh_backend_get_description (SeahorseBackend *backend)
+{
+	return _("Keys used to connect securely to other computers");
+}
+
+static GtkActionGroup *
+seahorse_ssh_backend_get_actions (SeahorseBackend *backend)
+{
+	return NULL;
 }
 
 static void
@@ -83,18 +107,20 @@ seahorse_ssh_backend_get_property (GObject *obj,
                                    GValue *value,
                                    GParamSpec *pspec)
 {
+	SeahorseBackend *backend = SEAHORSE_BACKEND (obj);
+
 	switch (prop_id) {
 	case PROP_NAME:
-		g_value_set_string (value, SEAHORSE_SSH_NAME);
+		g_value_set_string (value, seahorse_ssh_backend_get_name (backend));
 		break;
 	case PROP_LABEL:
-		g_value_set_string (value, _("Secure Shell"));
+		g_value_set_string (value, seahorse_ssh_backend_get_label (backend));
 		break;
 	case PROP_DESCRIPTION:
-		g_value_set_string (value, _("Keys used to connect securely to other computers"));
+		g_value_set_string (value, seahorse_ssh_backend_get_description (backend));
 		break;
 	case PROP_ACTIONS:
-		g_value_set_object (value, NULL);
+		g_value_take_object (value, seahorse_ssh_backend_get_actions (backend));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
@@ -180,6 +206,10 @@ static void
 seahorse_ssh_backend_iface (SeahorseBackendIface *iface)
 {
 	iface->lookup_place = seahorse_ssh_backend_lookup_place;
+	iface->get_actions = seahorse_ssh_backend_get_actions;
+	iface->get_description = seahorse_ssh_backend_get_description;
+	iface->get_label = seahorse_ssh_backend_get_label;
+	iface->get_name = seahorse_ssh_backend_get_name;
 }
 
 void
