@@ -25,10 +25,16 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <gcr/gcr.h>
 
-#define SEAHORSE_SSH_TYPE_STR "openssh"
-#define SEAHORSE_SSH_TYPE g_quark_from_string ("openssh")
-#define SEAHORSE_SSH_STOCK_ICON "seahorse-key-ssh"
+#define SEAHORSE_SSH_NAME "openssh"
+#define SEAHORSE_SSH_TYPE_STR SEAHORSE_SSH_NAME
+#define SEAHORSE_SSH (g_quark_from_static_string (SEAHORSE_SSH_NAME))
 
+#ifdef WITH_SSH
+
+void       seahorse_ssh_backend_initialize    (void);
+
+#endif /* WITH_SSH */
 
 #endif
